@@ -34,8 +34,13 @@ sub DESTROY {
 
 sub write {
     my ($self, $oid, $source) = @_;
-    if (tell $source) {
-        &write_io;
+    my $tell;
+    {
+        local $^W = 0;
+        $tell = tell($source)
+    }
+    if ($tell) {
+        &write_handle;
     } else {
         &write_data;
     }
